pygeodesy.ltpTuples.Uvw

Package pygeodesy :: Module ltpTuples :: Class Uvw |
[frames] | no frames]

# Class Uvw

           object --+
                    |
         named._Named --+
                        |
         named._NamedBase --+
                            |
    vector3dBase.Vector3dBase --+
                                |
                vector3d.Vector3d --+
                                    |
                            _Vector3d --+
                                        |
                                       Uvw

3-D `u-v-w` (UVW) components.

Instance Methods
__init__(self, u_uvw, v=0, w=0, **name) New Uvw. |
toEnu(self, location, Enu=<class 'pygeodesy.ltpTuples.Enu'>, **name_Enu_kwds) Get the East, North, Up (ENU) components at a location. |
Inherited from `_Vector3d`: `toRepr`, `toStr` Inherited from `vector3d.Vector3d`: `bearing`, `circin6`, `circum3`, `circum4_`, `iscolinearWith`, `meeus2`, `nearestOn`, `nearestOn6`, `parse`, `radii11`, `soddy4`, `toCartesian`, `trilaterate2d2`, `trilaterate3d2` Inherited from `vector3dBase.Vector3dBase`: `__abs__`, `__add__`, `__bool__`, `__ceil__`, `__cmp__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floor__`, `__floordiv__`, `__ge__`, `__gt__`, `__hash__`, `__iadd__`, `__idiv__`, `__ifloordiv__`, `__imatmul__`, `__imod__`, `__imul__`, `__int__`, `__ipow__`, `__isub__`, `__itruediv__`, `__le__`, `__long__`, `__lt__`, `__matmul__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmatmul__`, `__rmod__`, `__rmul__`, `__round__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__sub__`, `__truediv__`, `__trunc__`, `angleTo`, `apply`, `bools`, `cmp`, `cross`, `dividedBy`, `dividedBy_`, `dot`, `equals`, `equirectangular`, `fabs`, `floats`, `floorDividedBy`, `floorDividedBy_`, `intermediateTo`, `ints`, `isconjugateTo`, `isequalTo`, `minus`, `minus_`, `negate`, `others`, `plus`, `plus_`, `pow`, `rotate`, `rotateAround`, `sum`, `times`, `times_`, `to3xyz`, `unit` Inherited from `named._NamedBase`: `__repr__`, `__str__` Inherited from `named._Named`: `__format__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| u Get the X component (`float`).
| uvw Get the `(U, V, W)` components (Uvw3Tuple`(u, v, w)`).
| v Get the Y component (`float`).
| w Get the Z component (`float`).
Inherited from `vector3dBase.Vector3dBase`: `crosserrors`, `euclid`, `homogeneous`, `length`, `length2`, `x`, `x2y2z2`, `x2y2z23`, `xyz`, `xyz3`, `y`, `z` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, u_uvw, v=0, w=0, **name) (Constructor) |
New Uvw. Arguments: `u_uvw` - Scalar U component (`meter`) or a previous instance (Uvw, Uvw3Tuple, Vector3d). `v` - V component (`meter`), iff `u_uvw` is `meter`, ignored otherwise. `w` - W component (`meter`), iff `u_uvw` is `meter`, ignored otherwise. `name` - Optional `name=NN` (`str`). Raises: `TypeError` - Invalid `east_enu`. `UnitError` - Invalid `east_enu`, `v` or `w`. Overrides: object.__init__

### toEnu (self, location, Enu=<class 'pygeodesy.ltpTuples.Enu'>, **name_Enu_kwds) |
Get the East, North, Up (ENU) components at a location. Arguments: `location` - The geodetic (`LatLon`) or geocentric (`Cartesian`, Vector3d) location from where to cast the Los. `Enu` - Class to return ENU (Enu) or `None`. `name_Enu_kwds` - Optional `name=NN` (`str`) and optionally, additional Enu keyword arguments, ignored if `Enu is None`. Returns: An `Enu` instance or an Enu4Tuple`(east, north, up, ltp)` with `ltp=None` if `Enu is None`. Raises: `TypeError` - Invalid `location`, `Enu` or `name_Enu_kwds` item. See Also: Function lookAtSpheroid.

Property Details

### u Get the X component (`float`). Get method: x(self) - Get the X component (`float`). Set method: x(self, x) - Set the X component, if different (`float`). Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### uvw Get the `(U, V, W)` components (Uvw3Tuple`(u, v, w)`). Get method: uvw(self) - Get the `(U, V, W)` components (Uvw3Tuple`(u, v, w)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### v Get the Y component (`float`). Get method: y(self) - Get the Y component (`float`). Set method: y(self, y) - Set the Y component, if different (`float`). Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### w Get the Z component (`float`). Get method: z(self) - Get the Z component (`float`). Set method: z(self, z) - Set the Z component, if different (`float`). Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.